# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import policies_pb2 as admin_dot_v1_dot_policies__pb2


class PolicyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetPolicies = channel.unary_unary(
                '/admin.v1.PolicyService/GetPolicies',
                request_serializer=admin_dot_v1_dot_policies__pb2.GetPoliciesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.GetPoliciesResponse.FromString,
                )
        self.GetPolicy = channel.unary_unary(
                '/admin.v1.PolicyService/GetPolicy',
                request_serializer=admin_dot_v1_dot_policies__pb2.GetPolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.GetPolicyResponse.FromString,
                )
        self.GetPolicyV2 = channel.unary_unary(
                '/admin.v1.PolicyService/GetPolicyV2',
                request_serializer=admin_dot_v1_dot_policies__pb2.GetPolicyV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.GetPolicyV2Response.FromString,
                )
        self.CreatePolicy = channel.unary_unary(
                '/admin.v1.PolicyService/CreatePolicy',
                request_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicyResponse.FromString,
                )
        self.CreatePolicyV2 = channel.unary_unary(
                '/admin.v1.PolicyService/CreatePolicyV2',
                request_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicyV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicyV2Response.FromString,
                )
        self.UpdatePolicy = channel.unary_unary(
                '/admin.v1.PolicyService/UpdatePolicy',
                request_serializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyResponse.FromString,
                )
        self.UpdatePolicyV2 = channel.unary_unary(
                '/admin.v1.PolicyService/UpdatePolicyV2',
                request_serializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Request.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Response.FromString,
                )
        self.DeletePolicy = channel.unary_unary(
                '/admin.v1.PolicyService/DeletePolicy',
                request_serializer=admin_dot_v1_dot_policies__pb2.DeletePolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.DeletePolicyResponse.FromString,
                )
        self.DryRunPolicies = channel.unary_unary(
                '/admin.v1.PolicyService/DryRunPolicies',
                request_serializer=admin_dot_v1_dot_policies__pb2.DryRunPoliciesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.DryRunPoliciesResponse.FromString,
                )
        self.EvaluatePolicyValidity = channel.unary_unary(
                '/admin.v1.PolicyService/EvaluatePolicyValidity',
                request_serializer=admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityResponse.FromString,
                )
        self.CreatePolicySuggestion = channel.unary_unary(
                '/admin.v1.PolicyService/CreatePolicySuggestion',
                request_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionResponse.FromString,
                )


class PolicyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicyV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicyV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePolicyV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DryRunPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EvaluatePolicyValidity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicySuggestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolicyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicies,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.GetPoliciesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.GetPoliciesResponse.SerializeToString,
            ),
            'GetPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicy,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.GetPolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.GetPolicyResponse.SerializeToString,
            ),
            'GetPolicyV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicyV2,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.GetPolicyV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.GetPolicyV2Response.SerializeToString,
            ),
            'CreatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicy,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicyResponse.SerializeToString,
            ),
            'CreatePolicyV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicyV2,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicyV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicyV2Response.SerializeToString,
            ),
            'UpdatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePolicy,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyResponse.SerializeToString,
            ),
            'UpdatePolicyV2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePolicyV2,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Request.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Response.SerializeToString,
            ),
            'DeletePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePolicy,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.DeletePolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.DeletePolicyResponse.SerializeToString,
            ),
            'DryRunPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.DryRunPolicies,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.DryRunPoliciesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.DryRunPoliciesResponse.SerializeToString,
            ),
            'EvaluatePolicyValidity': grpc.unary_unary_rpc_method_handler(
                    servicer.EvaluatePolicyValidity,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityResponse.SerializeToString,
            ),
            'CreatePolicySuggestion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicySuggestion,
                    request_deserializer=admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.PolicyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PolicyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/GetPolicies',
            admin_dot_v1_dot_policies__pb2.GetPoliciesRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.GetPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/GetPolicy',
            admin_dot_v1_dot_policies__pb2.GetPolicyRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.GetPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicyV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/GetPolicyV2',
            admin_dot_v1_dot_policies__pb2.GetPolicyV2Request.SerializeToString,
            admin_dot_v1_dot_policies__pb2.GetPolicyV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/CreatePolicy',
            admin_dot_v1_dot_policies__pb2.CreatePolicyRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.CreatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicyV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/CreatePolicyV2',
            admin_dot_v1_dot_policies__pb2.CreatePolicyV2Request.SerializeToString,
            admin_dot_v1_dot_policies__pb2.CreatePolicyV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/UpdatePolicy',
            admin_dot_v1_dot_policies__pb2.UpdatePolicyRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.UpdatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePolicyV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/UpdatePolicyV2',
            admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Request.SerializeToString,
            admin_dot_v1_dot_policies__pb2.UpdatePolicyV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/DeletePolicy',
            admin_dot_v1_dot_policies__pb2.DeletePolicyRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.DeletePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DryRunPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/DryRunPolicies',
            admin_dot_v1_dot_policies__pb2.DryRunPoliciesRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.DryRunPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EvaluatePolicyValidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/EvaluatePolicyValidity',
            admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.EvaluatePolicyValidityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicySuggestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.PolicyService/CreatePolicySuggestion',
            admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionRequest.SerializeToString,
            admin_dot_v1_dot_policies__pb2.CreatePolicySuggestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from .types.v1 import log_pb2 as _log_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLogsRequest(_message.Message):
    __slots__ = ["limit", "offset", "filter"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    offset: int
    filter: str
    def __init__(self, limit: _Optional[int] = ..., offset: _Optional[int] = ..., filter: _Optional[str] = ...) -> None: ...

class GetLogByIDRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLogsResponse(_message.Message):
    __slots__ = ["logs", "has_more"]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    HAS_MORE_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[_log_pb2.FormalLog]
    has_more: bool
    def __init__(self, logs: _Optional[_Iterable[_Union[_log_pb2.FormalLog, _Mapping]]] = ..., has_more: bool = ...) -> None: ...

class GetLogByIDResponse(_message.Message):
    __slots__ = ["log"]
    LOG_FIELD_NUMBER: _ClassVar[int]
    log: _log_pb2.FormalLog
    def __init__(self, log: _Optional[_Union[_log_pb2.FormalLog, _Mapping]] = ...) -> None: ...

class GetEventBySessionRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetEventBySessionResponse(_message.Message):
    __slots__ = ["event_data"]
    EVENT_DATA_FIELD_NUMBER: _ClassVar[int]
    event_data: _containers.RepeatedCompositeFieldContainer[EventData]
    def __init__(self, event_data: _Optional[_Iterable[_Union[EventData, _Mapping]]] = ...) -> None: ...

class EventData(_message.Message):
    __slots__ = ["timestamp", "type", "session_id", "bytes", "offset"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    type: str
    session_id: str
    bytes: int
    offset: int
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., type: _Optional[str] = ..., session_id: _Optional[str] = ..., bytes: _Optional[int] = ..., offset: _Optional[int] = ...) -> None: ...

class GetDataBySessionRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class SshData(_message.Message):
    __slots__ = ["timestamp", "data", "message_type"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_TYPE_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    data: bytes
    message_type: str
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., data: _Optional[bytes] = ..., message_type: _Optional[str] = ...) -> None: ...

class GetDataBySessionResponse(_message.Message):
    __slots__ = ["ssh_data"]
    SSH_DATA_FIELD_NUMBER: _ClassVar[int]
    ssh_data: _containers.RepeatedCompositeFieldContainer[SshData]
    def __init__(self, ssh_data: _Optional[_Iterable[_Union[SshData, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/domain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/domain.proto\x12\x11\x61\x64min.v1.types.v1\"\xce\x01\n\x06\x44omain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x06owners\x18\x04 \x03(\x0b\x32\x18.admin.v1.types.v1.OwnerR\x06owners\x12%\n\x0e\x65xcluded_paths\x18\x05 \x03(\tR\rexcludedPaths\x12%\n\x0eincluded_paths\x18\x06 \x03(\tR\rincludedPaths\"E\n\x05Owner\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x1b\n\tobject_id\x18\x02 \x01(\tR\x08objectIdB\xde\x01\n\x15\x63om.admin.v1.types.v1B\x0b\x44omainProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.domain_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013DomainProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_DOMAIN']._serialized_start=54
  _globals['_DOMAIN']._serialized_end=260
  _globals['_OWNER']._serialized_start=262
  _globals['_OWNER']._serialized_end=331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/sidecar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61\x64min/v1/types/v1/sidecar.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x06\n\x07Sidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12(\n\x10\x63loud_account_id\x18\x03 \x01(\tR\x0e\x63loudAccountId\x12G\n\x0e\x63loud_provider\x18\x04 \x01(\x0e\x32 .admin.v1.types.v1.CloudProviderR\rcloudProvider\x12!\n\x0c\x63loud_region\x18\x05 \x01(\tR\x0b\x63loudRegion\x12\x1e\n\ntechnology\x18\x06 \x01(\tR\ntechnology\x12\'\n\x0f\x64\x65ployment_type\x18\x07 \x01(\tR\x0e\x64\x65ploymentType\x12!\n\x0cnetwork_type\x18\x08 \x01(\tR\x0bnetworkType\x12!\n\x0c\x64\x61taplane_id\x18\t \x01(\tR\x0b\x64\x61taplaneId\x12!\n\x0c\x64\x61tastore_id\x18\n \x01(\tR\x0b\x64\x61tastoreId\x12\x1a\n\x08\x64\x65ployed\x18\x0b \x01(\x08R\x08\x64\x65ployed\x12\x18\n\x07version\x18\x0c \x01(\tR\x07version\x12\'\n\x0f\x66ormal_hostname\x18\r \x01(\tR\x0e\x66ormalHostname\x12\x38\n\x18server_connection_status\x18\x0e \x01(\tR\x16serverConnectionStatus\x12!\n\x0cproxy_status\x18\x0f \x01(\tR\x0bproxyStatus\x12\x1b\n\tfail_open\x18\x10 \x01(\x08R\x08\x66\x61ilOpen\x12,\n\x12global_kms_decrypt\x18\x11 \x01(\x08R\x10globalKmsDecrypt\x12\x1e\n\x0bssh_rsa_key\x18\x12 \x01(\x0cR\tsshRsaKey\x12\x30\n\x14server_error_message\x18\x13 \x01(\tR\x12serverErrorMessage\x12\x39\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt*j\n\x0e\x44\x65ploymentType\x12\x1f\n\x1b\x44\x45PLOYMENT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x44\x45PLOYMENT_TYPE_ONPREM\x10\x01\x12\x1b\n\x17\x44\x45PLOYMENT_TYPE_MANAGED\x10\x02*\x90\x01\n\x0bNetworkType\x12\x1c\n\x18NETWORK_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cNETWORK_TYPE_INTERNET_FACING\x10\x01\x12\x19\n\x15NETWORK_TYPE_INTERNAL\x10\x02\x12&\n\"NETWORK_TYPE_INTERNET_AND_INTERNAL\x10\x03*y\n\rCloudProvider\x12\x1e\n\x1a\x43LOUD_PROVIDER_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43LOUD_PROVIDER_AWS\x10\x01\x12\x18\n\x14\x43LOUD_PROVIDER_AZURE\x10\x02\x12\x16\n\x12\x43LOUD_PROVIDER_GCP\x10\x03\x42\xdf\x01\n\x15\x63om.admin.v1.types.v1B\x0cSidecarProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.sidecar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\014SidecarProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_DEPLOYMENTTYPE']._serialized_start=867
  _globals['_DEPLOYMENTTYPE']._serialized_end=973
  _globals['_NETWORKTYPE']._serialized_start=976
  _globals['_NETWORKTYPE']._serialized_end=1120
  _globals['_CLOUDPROVIDER']._serialized_start=1122
  _globals['_CLOUDPROVIDER']._serialized_end=1243
  _globals['_SIDECAR']._serialized_start=88
  _globals['_SIDECAR']._serialized_end=865
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDirectoryRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDirectoryResponse(_message.Message):
    __slots__ = ["directory"]
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    directory: Directory
    def __init__(self, directory: _Optional[_Union[Directory, _Mapping]] = ...) -> None: ...

class Directory(_message.Message):
    __slots__ = ["id", "name", "idp_id", "directory_id", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IDP_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    idp_id: str
    directory_id: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., idp_id: _Optional[str] = ..., directory_id: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class GetGroupsByDirectoryIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetGroupsByDirectoryIdResponse(_message.Message):
    __slots__ = ["groups"]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[DirectorySyncGroup]
    def __init__(self, groups: _Optional[_Iterable[_Union[DirectorySyncGroup, _Mapping]]] = ...) -> None: ...

class GetUsersByDirectoryIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetUsersByDirectoryIdResponse(_message.Message):
    __slots__ = ["users"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[WorkUser]
    def __init__(self, users: _Optional[_Iterable[_Union[WorkUser, _Mapping]]] = ...) -> None: ...

class GetWorkOsGroupByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetWorkOsGroupByIdResponse(_message.Message):
    __slots__ = ["group"]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: DirectorySyncGroup
    def __init__(self, group: _Optional[_Union[DirectorySyncGroup, _Mapping]] = ...) -> None: ...

class DirectorySyncGroup(_message.Message):
    __slots__ = ["id", "name", "idp_id", "directory_id", "created_at", "updated_at", "mapped_formal_group_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IDP_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    MAPPED_FORMAL_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    idp_id: str
    directory_id: str
    created_at: str
    updated_at: str
    mapped_formal_group_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., idp_id: _Optional[str] = ..., directory_id: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., mapped_formal_group_id: _Optional[str] = ...) -> None: ...

class UserEmail(_message.Message):
    __slots__ = ["primary", "value", "type"]
    PRIMARY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    primary: bool
    value: str
    type: str
    def __init__(self, primary: bool = ..., value: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class UserGroup(_message.Message):
    __slots__ = ["object", "id", "name"]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    object: str
    id: str
    name: str
    def __init__(self, object: _Optional[str] = ..., id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class WorkUser(_message.Message):
    __slots__ = ["id", "idp_id", "directory_id", "username", "emails", "first_name", "last_name", "job_title", "state", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    IDP_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAILS_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    JOB_TITLE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    idp_id: str
    directory_id: str
    username: str
    emails: _containers.RepeatedCompositeFieldContainer[UserEmail]
    first_name: str
    last_name: str
    job_title: str
    state: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., idp_id: _Optional[str] = ..., directory_id: _Optional[str] = ..., username: _Optional[str] = ..., emails: _Optional[_Iterable[_Union[UserEmail, _Mapping]]] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., job_title: _Optional[str] = ..., state: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class Users(_message.Message):
    __slots__ = ["users"]
    USERS_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[WorkUser]
    def __init__(self, users: _Optional[_Iterable[_Union[WorkUser, _Mapping]]] = ...) -> None: ...

class Group(_message.Message):
    __slots__ = ["id", "name", "description", "active", "status", "created_at", "user_ids", "dsync_group_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    DSYNC_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    active: bool
    status: str
    created_at: _timestamp_pb2.Timestamp
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    dsync_group_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., active: bool = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user_ids: _Optional[_Iterable[str]] = ..., dsync_group_id: _Optional[str] = ...) -> None: ...

class GroupPair(_message.Message):
    __slots__ = ["f_group", "d_group"]
    F_GROUP_FIELD_NUMBER: _ClassVar[int]
    D_GROUP_FIELD_NUMBER: _ClassVar[int]
    f_group: Group
    d_group: DirectorySyncGroup
    def __init__(self, f_group: _Optional[_Union[Group, _Mapping]] = ..., d_group: _Optional[_Union[DirectorySyncGroup, _Mapping]] = ...) -> None: ...

class GetDirectoryGroupsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDirectoryGroupsResponse(_message.Message):
    __slots__ = ["directory_ids", "f_groups", "d_groups", "group_pairs", "d_group_users"]
    class DGroupUsersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Users
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Users, _Mapping]] = ...) -> None: ...
    DIRECTORY_IDS_FIELD_NUMBER: _ClassVar[int]
    F_GROUPS_FIELD_NUMBER: _ClassVar[int]
    D_GROUPS_FIELD_NUMBER: _ClassVar[int]
    GROUP_PAIRS_FIELD_NUMBER: _ClassVar[int]
    D_GROUP_USERS_FIELD_NUMBER: _ClassVar[int]
    directory_ids: _containers.RepeatedScalarFieldContainer[str]
    f_groups: _containers.RepeatedCompositeFieldContainer[Group]
    d_groups: _containers.RepeatedCompositeFieldContainer[DirectorySyncGroup]
    group_pairs: _containers.RepeatedCompositeFieldContainer[GroupPair]
    d_group_users: _containers.MessageMap[str, Users]
    def __init__(self, directory_ids: _Optional[_Iterable[str]] = ..., f_groups: _Optional[_Iterable[_Union[Group, _Mapping]]] = ..., d_groups: _Optional[_Iterable[_Union[DirectorySyncGroup, _Mapping]]] = ..., group_pairs: _Optional[_Iterable[_Union[GroupPair, _Mapping]]] = ..., d_group_users: _Optional[_Mapping[str, Users]] = ...) -> None: ...

class UpdateDirectoryGroupSyncRequest(_message.Message):
    __slots__ = ["f_group_id", "d_group_id", "deselected_user_ids"]
    class DeselectedUserIdsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: bool
        def __init__(self, key: _Optional[str] = ..., value: bool = ...) -> None: ...
    F_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    D_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    DESELECTED_USER_IDS_FIELD_NUMBER: _ClassVar[int]
    f_group_id: str
    d_group_id: str
    deselected_user_ids: _containers.ScalarMap[str, bool]
    def __init__(self, f_group_id: _Optional[str] = ..., d_group_id: _Optional[str] = ..., deselected_user_ids: _Optional[_Mapping[str, bool]] = ...) -> None: ...

class UpdateDirectoryGroupSyncResponse(_message.Message):
    __slots__ = ["f_group_id"]
    F_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    f_group_id: str
    def __init__(self, f_group_id: _Optional[str] = ...) -> None: ...

class GetDSyncPortalRequest(_message.Message):
    __slots__ = ["auth_token"]
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    auth_token: str
    def __init__(self, auth_token: _Optional[str] = ...) -> None: ...

class GetDSyncPortalResponse(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: str
    def __init__(self, link: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import etl_pb2 as admin_dot_v1_dot_etl__pb2


class ETLServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConnectors = channel.unary_unary(
                '/admin.v1.ETLService/GetConnectors',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.FromString,
                )
        self.GetConnectorByDbName = channel.unary_unary(
                '/admin.v1.ETLService/GetConnectorByDbName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.FromString,
                )
        self.GetDestinations = channel.unary_unary(
                '/admin.v1.ETLService/GetDestinations',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.FromString,
                )
        self.GetDestinationByID = channel.unary_unary(
                '/admin.v1.ETLService/GetDestinationByID',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.FromString,
                )
        self.GetGroups = channel.unary_unary(
                '/admin.v1.ETLService/GetGroups',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetGroupsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetGroupsResponse.FromString,
                )
        self.GetLineageSchemas = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageSchemas',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.FromString,
                )
        self.GetLineageSchemaByName = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageSchemaByName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.FromString,
                )
        self.GetLineageTables = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageTables',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.FromString,
                )
        self.GetLineageTableByName = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageTableByName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.FromString,
                )
        self.GetLineageColumns = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageColumns',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.FromString,
                )
        self.GetLineageColumnsByTable = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageColumnsByTable',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.FromString,
                )


class ETLServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConnectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectorByDbName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDestinations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDestinationByID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageSchemas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageSchemaByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageTableByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageColumns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageColumnsByTable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ETLServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConnectors': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectors,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.SerializeToString,
            ),
            'GetConnectorByDbName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectorByDbName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.SerializeToString,
            ),
            'GetDestinations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDestinations,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.SerializeToString,
            ),
            'GetDestinationByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDestinationByID,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.SerializeToString,
            ),
            'GetGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroups,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetGroupsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetGroupsResponse.SerializeToString,
            ),
            'GetLineageSchemas': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageSchemas,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.SerializeToString,
            ),
            'GetLineageSchemaByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageSchemaByName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.SerializeToString,
            ),
            'GetLineageTables': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageTables,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.SerializeToString,
            ),
            'GetLineageTableByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageTableByName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.SerializeToString,
            ),
            'GetLineageColumns': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageColumns,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.SerializeToString,
            ),
            'GetLineageColumnsByTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageColumnsByTable,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.ETLService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ETLService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConnectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetConnectors',
            admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnectorByDbName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetConnectorByDbName',
            admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDestinations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetDestinations',
            admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDestinationByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetDestinationByID',
            admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetGroups',
            admin_dot_v1_dot_etl__pb2.GetGroupsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageSchemas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageSchemas',
            admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageSchemaByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageSchemaByName',
            admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageTables',
            admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageTableByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageTableByName',
            admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageColumns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageColumns',
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageColumnsByTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageColumnsByTable',
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/native_user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61\x64min/v1/native_user.proto\x12\x08\x61\x64min.v1\"\xb7\x01\n\x17\x43reateNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\x12$\n\x0euse_as_default\x18\x04 \x01(\x08R\x0cuseAsDefault\"Q\n\x18\x43reateNativeUserResponse\x12\x35\n\x0bnative_user\x18\x01 \x01(\x0b\x32\x14.admin.v1.NativeUserR\nnativeUser\";\n\x15GetNativeUsersRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\"\xc4\x01\n\x16GetNativeUsersResponse\x12T\n\x0cnative_users\x18\x01 \x03(\x0b\x32\x31.admin.v1.GetNativeUsersResponse.NativeUsersEntryR\x0bnativeUsers\x1aT\n\x10NativeUsersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.admin.v1.NativeUserR\x05value:\x02\x38\x01\"`\n\x14GetNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\"N\n\x15GetNativeUserResponse\x12\x35\n\x0bnative_user\x18\x01 \x01(\x0b\x32\x14.admin.v1.NativeUserR\nnativeUser\"\xf6\x01\n\nNativeUser\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\x12$\n\x0euse_as_default\x18\x04 \x01(\x08R\x0cuseAsDefault\x12\x1d\n\ncreated_at\x18\x05 \x01(\x03R\tcreatedAt\x12\x14\n\x05users\x18\x06 \x03(\tR\x05users\x12\x16\n\x06groups\x18\x07 \x03(\tR\x06groups\"c\n\x17\x44\x65leteNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\"\x1a\n\x18\x44\x65leteNativeUserResponse\"\x97\x01\n\x1dUpdateNativeUserSecretRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\" \n\x1eUpdateNativeUserSecretResponse\"i\n\x1dSetNativeUserAsDefaultRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\" \n\x1eSetNativeUserAsDefaultResponse\"\xc2\x01\n#CreateNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12\x1f\n\x0bidentity_id\x18\x03 \x01(\tR\nidentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x04 \x01(\tR\x12\x66ormalIdentityType\"T\n$CreateNativeUserIdentityLinkResponse\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"g\n GetNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\"\xc4\x01\n%CreateNativeUserIdentityLinkV2Request\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12\x1f\n\x0bidentity_id\x18\x03 \x01(\tR\nidentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x04 \x01(\tR\x12\x66ormalIdentityType\"V\n&CreateNativeUserIdentityLinkV2Response\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"Q\n!GetNativeUserIdentityLinkResponse\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"j\n#DeleteNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\"&\n$DeleteNativeUserIdentityLinkResponse\"\xba\x01\n\x0eNativeUserLink\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12,\n\x12\x66ormal_identity_id\x18\x02 \x01(\tR\x10\x66ormalIdentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x03 \x01(\tR\x12\x66ormalIdentityType\x12$\n\x0enative_user_id\x18\x04 \x01(\tR\x0cnativeUserId2\xc4\x08\n\x11NativeUserService\x12Y\n\x10\x43reateNativeUser\x12!.admin.v1.CreateNativeUserRequest\x1a\".admin.v1.CreateNativeUserResponse\x12P\n\rGetNativeUser\x12\x1e.admin.v1.GetNativeUserRequest\x1a\x1f.admin.v1.GetNativeUserResponse\x12S\n\x0eGetNativeUsers\x12\x1f.admin.v1.GetNativeUsersRequest\x1a .admin.v1.GetNativeUsersResponse\x12Y\n\x10\x44\x65leteNativeUser\x12!.admin.v1.DeleteNativeUserRequest\x1a\".admin.v1.DeleteNativeUserResponse\x12k\n\x16UpdateNativeUserSecret\x12\'.admin.v1.UpdateNativeUserSecretRequest\x1a(.admin.v1.UpdateNativeUserSecretResponse\x12k\n\x16SetNativeUserAsDefault\x12\'.admin.v1.SetNativeUserAsDefaultRequest\x1a(.admin.v1.SetNativeUserAsDefaultResponse\x12}\n\x1c\x43reateNativeUserIdentityLink\x12-.admin.v1.CreateNativeUserIdentityLinkRequest\x1a..admin.v1.CreateNativeUserIdentityLinkResponse\x12\x83\x01\n\x1e\x43reateNativeUserIdentityLinkV2\x12/.admin.v1.CreateNativeUserIdentityLinkV2Request\x1a\x30.admin.v1.CreateNativeUserIdentityLinkV2Response\x12t\n\x19GetNativeUserIdentityLink\x12*.admin.v1.GetNativeUserIdentityLinkRequest\x1a+.admin.v1.GetNativeUserIdentityLinkResponse\x12}\n\x1c\x44\x65leteNativeUserIdentityLink\x12-.admin.v1.DeleteNativeUserIdentityLinkRequest\x1a..admin.v1.DeleteNativeUserIdentityLinkResponseB\xaa\x01\n\x0c\x63om.admin.v1B\x0fNativeUserProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.native_user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017NativeUserProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._options = None
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENATIVEUSERREQUEST']._serialized_start=41
  _globals['_CREATENATIVEUSERREQUEST']._serialized_end=224
  _globals['_CREATENATIVEUSERRESPONSE']._serialized_start=226
  _globals['_CREATENATIVEUSERRESPONSE']._serialized_end=307
  _globals['_GETNATIVEUSERSREQUEST']._serialized_start=309
  _globals['_GETNATIVEUSERSREQUEST']._serialized_end=368
  _globals['_GETNATIVEUSERSRESPONSE']._serialized_start=371
  _globals['_GETNATIVEUSERSRESPONSE']._serialized_end=567
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_start=483
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_end=567
  _globals['_GETNATIVEUSERREQUEST']._serialized_start=569
  _globals['_GETNATIVEUSERREQUEST']._serialized_end=665
  _globals['_GETNATIVEUSERRESPONSE']._serialized_start=667
  _globals['_GETNATIVEUSERRESPONSE']._serialized_end=745
  _globals['_NATIVEUSER']._serialized_start=748
  _globals['_NATIVEUSER']._serialized_end=994
  _globals['_DELETENATIVEUSERREQUEST']._serialized_start=996
  _globals['_DELETENATIVEUSERREQUEST']._serialized_end=1095
  _globals['_DELETENATIVEUSERRESPONSE']._serialized_start=1097
  _globals['_DELETENATIVEUSERRESPONSE']._serialized_end=1123
  _globals['_UPDATENATIVEUSERSECRETREQUEST']._serialized_start=1126
  _globals['_UPDATENATIVEUSERSECRETREQUEST']._serialized_end=1277
  _globals['_UPDATENATIVEUSERSECRETRESPONSE']._serialized_start=1279
  _globals['_UPDATENATIVEUSERSECRETRESPONSE']._serialized_end=1311
  _globals['_SETNATIVEUSERASDEFAULTREQUEST']._serialized_start=1313
  _globals['_SETNATIVEUSERASDEFAULTREQUEST']._serialized_end=1418
  _globals['_SETNATIVEUSERASDEFAULTRESPONSE']._serialized_start=1420
  _globals['_SETNATIVEUSERASDEFAULTRESPONSE']._serialized_end=1452
  _globals['_CREATENATIVEUSERIDENTITYLINKREQUEST']._serialized_start=1455
  _globals['_CREATENATIVEUSERIDENTITYLINKREQUEST']._serialized_end=1649
  _globals['_CREATENATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=1651
  _globals['_CREATENATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=1735
  _globals['_GETNATIVEUSERIDENTITYLINKREQUEST']._serialized_start=1737
  _globals['_GETNATIVEUSERIDENTITYLINKREQUEST']._serialized_end=1840
  _globals['_CREATENATIVEUSERIDENTITYLINKV2REQUEST']._serialized_start=1843
  _globals['_CREATENATIVEUSERIDENTITYLINKV2REQUEST']._serialized_end=2039
  _globals['_CREATENATIVEUSERIDENTITYLINKV2RESPONSE']._serialized_start=2041
  _globals['_CREATENATIVEUSERIDENTITYLINKV2RESPONSE']._serialized_end=2127
  _globals['_GETNATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=2129
  _globals['_GETNATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=2210
  _globals['_DELETENATIVEUSERIDENTITYLINKREQUEST']._serialized_start=2212
  _globals['_DELETENATIVEUSERIDENTITYLINKREQUEST']._serialized_end=2318
  _globals['_DELETENATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=2320
  _globals['_DELETENATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=2358
  _globals['_NATIVEUSERLINK']._serialized_start=2361
  _globals['_NATIVEUSERLINK']._serialized_end=2547
  _globals['_NATIVEUSERSERVICE']._serialized_start=2550
  _globals['_NATIVEUSERSERVICE']._serialized_end=3642
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_github_pb2 import (
	InstallGithubAppRequest,
	InstallGithubAppResponse,
	GetGithubAppForOrgRequest,
	GetGithubAppForOrgResponse,
)

from .gen.admin.v1.integration_github_pb2_grpc import GithubServiceStub
class GithubService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = GithubServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def InstallGithubApp(self, request: InstallGithubAppRequest) -> InstallGithubAppResponse:
		return self.stub.InstallGithubApp(request, metadata=self.headers)

	def GetGithubAppForOrg(self, request: GetGithubAppForOrgRequest) -> GetGithubAppForOrgResponse:
		return self.stub.GetGithubAppForOrg(request, metadata=self.headers)




import grpc


from .gen.admin.v1.integration_slack_pb2 import (
	CreateSlackIntegrationRequest,
	CreateSlackIntegrationResponse,
	GetSlackIntegrationRequest,
	GetSlackIntegrationResponse,
)

from .gen.admin.v1.integration_slack_pb2_grpc import SlackServiceStub
class SlackService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = SlackServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateSlackIntegration(self, request: CreateSlackIntegrationRequest) -> CreateSlackIntegrationResponse:
		return self.stub.CreateSlackIntegration(request, metadata=self.headers)

	def GetSlackIntegration(self, request: GetSlackIntegrationRequest) -> GetSlackIntegrationResponse:
		return self.stub.GetSlackIntegration(request, metadata=self.headers)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/identities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import external_id_pb2 as admin_dot_v1_dot_types_dot_v1_dot_external__id__pb2
from .types.v1 import group_pb2 as admin_dot_v1_dot_types_dot_v1_dot_group__pb2
from .types.v1 import user_pb2 as admin_dot_v1_dot_types_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/identities.proto\x12\x08\x61\x64min.v1\x1a#admin/v1/types/v1/external_id.proto\x1a\x1d\x61\x64min/v1/types/v1/group.proto\x1a\x1c\x61\x64min/v1/types/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%admin/v1/types/v1/list_metadata.proto\"W\n\x11ListGroupsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"J\n\x12\x43reateGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"%\n\x13GetGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12\x44\x65leteGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x12UpdateGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"D\n\x17LinkUsersToGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"F\n\x19LinkUsersToGroupV2Request\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"H\n\x1bUnlinkUsersFromGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"E\n\x13\x43reateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"F\n\x14GetGroupByIdResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13\x44\x65leteGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13UpdateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"\x8c\x01\n\x12ListGroupsResponse\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32\x18.admin.v1.types.v1.GroupR\x06groups\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"P\n\x18LinkUsersToGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"R\n\x1aLinkUsersToGroupV2Response\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"T\n\x1cUnlinkUsersFromGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"M\n\x15UserLinkGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"V\n\x10ListUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"\x88\x01\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x17.admin.v1.types.v1.UserR\x05users\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\xb8\x02\n\x11\x43reateUserRequest\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"^\n\x12\x43reateUserResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\"\xba\x02\n\x13\x43reateUserV2Request\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"&\n\x14\x43reateUserV2Response\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12GetUserByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"B\n\x13GetUserByIdResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x14\n\x12\x44\x65leteUserResponse\"\x89\x01\n\x11UpdateUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\"\x14\n\x12UpdateUserResponse\"0\n\x1eGetMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"S\n\x1fGetMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"4\n\"RefreshMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n#RefreshMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"+\n\x19GetUserExternalIdsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1aGetUserExternalIdsResponse\x12@\n\x0c\x65xternal_ids\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ExternalIdR\x0b\x65xternalIds\"\x8f\x01\n\x1aMapUserToExternalIdRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x06\x61pp_id\x18\x04 \x01(\tR\x05\x61ppId\"\x1d\n\x1bMapUserToExternalIdResponse\"?\n\x1e\x44\x65leteExternalIdMappingRequest\x12\x1d\n\nmapping_id\x18\x01 \x01(\tR\tmappingId\"!\n\x1f\x44\x65leteExternalIdMappingResponse2\xea\x07\n\x0bUserService\x12\x44\n\tListUsers\x12\x1a.admin.v1.ListUsersRequest\x1a\x1b.admin.v1.ListUsersResponse\x12G\n\nCreateUser\x12\x1b.admin.v1.CreateUserRequest\x1a\x1c.admin.v1.CreateUserResponse\x12M\n\x0c\x43reateUserV2\x12\x1d.admin.v1.CreateUserV2Request\x1a\x1e.admin.v1.CreateUserV2Response\x12J\n\x0bGetUserById\x12\x1c.admin.v1.GetUserByIdRequest\x1a\x1d.admin.v1.GetUserByIdResponse\x12G\n\nDeleteUser\x12\x1b.admin.v1.DeleteUserRequest\x1a\x1c.admin.v1.DeleteUserResponse\x12G\n\nUpdateUser\x12\x1b.admin.v1.UpdateUserRequest\x1a\x1c.admin.v1.UpdateUserResponse\x12n\n\x17GetMachineUserAuthToken\x12(.admin.v1.GetMachineUserAuthTokenRequest\x1a).admin.v1.GetMachineUserAuthTokenResponse\x12z\n\x1bRefreshMachineUserAuthToken\x12,.admin.v1.RefreshMachineUserAuthTokenRequest\x1a-.admin.v1.RefreshMachineUserAuthTokenResponse\x12_\n\x12GetUserExternalIds\x12#.admin.v1.GetUserExternalIdsRequest\x1a$.admin.v1.GetUserExternalIdsResponse\x12\x62\n\x13MapUserToExternalId\x12$.admin.v1.MapUserToExternalIdRequest\x1a%.admin.v1.MapUserToExternalIdResponse\x12n\n\x17\x44\x65leteExternalIdMapping\x12(.admin.v1.DeleteExternalIdMappingRequest\x1a).admin.v1.DeleteExternalIdMappingResponse2\xad\x05\n\x0cGroupService\x12J\n\x0b\x43reateGroup\x12\x1c.admin.v1.CreateGroupRequest\x1a\x1d.admin.v1.CreateGroupResponse\x12G\n\nListGroups\x12\x1b.admin.v1.ListGroupsRequest\x1a\x1c.admin.v1.ListGroupsResponse\x12M\n\x0cGetGroupById\x12\x1d.admin.v1.GetGroupByIdRequest\x1a\x1e.admin.v1.GetGroupByIdResponse\x12J\n\x0bUpdateGroup\x12\x1c.admin.v1.UpdateGroupRequest\x1a\x1d.admin.v1.UpdateGroupResponse\x12Y\n\x10LinkUsersToGroup\x12!.admin.v1.LinkUsersToGroupRequest\x1a\".admin.v1.LinkUsersToGroupResponse\x12_\n\x12LinkUsersToGroupV2\x12#.admin.v1.LinkUsersToGroupV2Request\x1a$.admin.v1.LinkUsersToGroupV2Response\x12\x65\n\x14UnlinkUsersFromGroup\x12%.admin.v1.UnlinkUsersFromGroupRequest\x1a&.admin.v1.UnlinkUsersFromGroupResponse\x12J\n\x0b\x44\x65leteGroup\x12\x1c.admin.v1.DeleteGroupRequest\x1a\x1d.admin.v1.DeleteGroupResponseB\xaa\x01\n\x0c\x63om.admin.v1B\x0fIdentitiesProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.identities_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017IdentitiesProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTGROUPSREQUEST']._serialized_start=209
  _globals['_LISTGROUPSREQUEST']._serialized_end=296
  _globals['_CREATEGROUPREQUEST']._serialized_start=298
  _globals['_CREATEGROUPREQUEST']._serialized_end=372
  _globals['_GETGROUPBYIDREQUEST']._serialized_start=374
  _globals['_GETGROUPBYIDREQUEST']._serialized_end=411
  _globals['_DELETEGROUPREQUEST']._serialized_start=413
  _globals['_DELETEGROUPREQUEST']._serialized_end=449
  _globals['_UPDATEGROUPREQUEST']._serialized_start=451
  _globals['_UPDATEGROUPREQUEST']._serialized_end=541
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_start=543
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_end=611
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_start=613
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_end=683
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_start=685
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_end=757
  _globals['_CREATEGROUPRESPONSE']._serialized_start=759
  _globals['_CREATEGROUPRESPONSE']._serialized_end=828
  _globals['_GETGROUPBYIDRESPONSE']._serialized_start=830
  _globals['_GETGROUPBYIDRESPONSE']._serialized_end=900
  _globals['_DELETEGROUPRESPONSE']._serialized_start=902
  _globals['_DELETEGROUPRESPONSE']._serialized_end=971
  _globals['_UPDATEGROUPRESPONSE']._serialized_start=973
  _globals['_UPDATEGROUPRESPONSE']._serialized_end=1042
  _globals['_LISTGROUPSRESPONSE']._serialized_start=1045
  _globals['_LISTGROUPSRESPONSE']._serialized_end=1185
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_start=1187
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_end=1267
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_start=1269
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_end=1351
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_start=1353
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_end=1437
  _globals['_USERLINKGROUPRESPONSE']._serialized_start=1439
  _globals['_USERLINKGROUPRESPONSE']._serialized_end=1516
  _globals['_LISTUSERSREQUEST']._serialized_start=1518
  _globals['_LISTUSERSREQUEST']._serialized_end=1604
  _globals['_LISTUSERSRESPONSE']._serialized_start=1607
  _globals['_LISTUSERSRESPONSE']._serialized_end=1743
  _globals['_CREATEUSERREQUEST']._serialized_start=1746
  _globals['_CREATEUSERREQUEST']._serialized_end=2058
  _globals['_CREATEUSERRESPONSE']._serialized_start=2060
  _globals['_CREATEUSERRESPONSE']._serialized_end=2154
  _globals['_CREATEUSERV2REQUEST']._serialized_start=2157
  _globals['_CREATEUSERV2REQUEST']._serialized_end=2471
  _globals['_CREATEUSERV2RESPONSE']._serialized_start=2473
  _globals['_CREATEUSERV2RESPONSE']._serialized_end=2511
  _globals['_GETUSERBYIDREQUEST']._serialized_start=2513
  _globals['_GETUSERBYIDREQUEST']._serialized_end=2549
  _globals['_GETUSERBYIDRESPONSE']._serialized_start=2551
  _globals['_GETUSERBYIDRESPONSE']._serialized_end=2617
  _globals['_DELETEUSERREQUEST']._serialized_start=2619
  _globals['_DELETEUSERREQUEST']._serialized_end=2654
  _globals['_DELETEUSERRESPONSE']._serialized_start=2656
  _globals['_DELETEUSERRESPONSE']._serialized_end=2676
  _globals['_UPDATEUSERREQUEST']._serialized_start=2679
  _globals['_UPDATEUSERREQUEST']._serialized_end=2816
  _globals['_UPDATEUSERRESPONSE']._serialized_start=2818
  _globals['_UPDATEUSERRESPONSE']._serialized_end=2838
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2840
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_end=2888
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=2890
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=2973
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2975
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3027
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3029
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3116
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_start=3118
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_end=3161
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_start=3163
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_end=3257
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_start=3260
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_end=3403
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_start=3405
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_end=3434
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_start=3436
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_end=3499
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_start=3501
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_end=3534
  _globals['_USERSERVICE']._serialized_start=3537
  _globals['_USERSERVICE']._serialized_end=4539
  _globals['_GROUPSERVICE']._serialized_start=4542
  _globals['_GROUPSERVICE']._serialized_end=5227
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/encryption.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/encryption.proto\x12\x08\x61\x64min.v1\"\xa2\x01\n1CreateOrUpdateDefaultFieldEncryptionPolicyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12%\n\x0e\x65ncryption_alg\x18\x02 \x01(\tR\rencryptionAlg\x12(\n\x10\x64\x61ta_key_storage\x18\x03 \x01(\tR\x0e\x64\x61taKeyStorage\"\xa3\x01\n2CreateOrUpdateDefaultFieldEncryptionPolicyResponse\x12m\n\x1f\x64\x65\x66\x61ult_field_encryption_policy\x18\x01 \x01(\x0b\x32&.admin.v1.DefaultFieldEncryptionPolicyR\x1c\x64\x65\x66\x61ultFieldEncryptionPolicy\"(\n&GetDefaultFieldEncryptionPolicyRequest\"\x98\x01\n\'GetDefaultFieldEncryptionPolicyResponse\x12m\n\x1f\x64\x65\x66\x61ult_field_encryption_policy\x18\x01 \x01(\x0b\x32&.admin.v1.DefaultFieldEncryptionPolicyR\x1c\x64\x65\x66\x61ultFieldEncryptionPolicy\"\xac\x01\n\x1c\x44\x65\x66\x61ultFieldEncryptionPolicy\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12%\n\x0e\x65ncryption_alg\x18\x02 \x01(\tR\rencryptionAlg\x12(\n\x10\x64\x61ta_key_storage\x18\x03 \x01(\tR\x0e\x64\x61taKeyStorage\x12\x1d\n\nupdated_at\x18\x05 \x01(\x03R\tupdatedAt\"\x9f\x01\n\x1c\x43reateFieldEncryptionRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1f\n\x0bkey_storage\x18\x02 \x01(\tR\nkeyStorage\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12\x10\n\x03\x61lg\x18\x04 \x01(\tR\x03\x61lg\x12!\n\x0c\x64\x61tastore_id\x18\x05 \x01(\tR\x0b\x64\x61tastoreId\"e\n\x1d\x43reateFieldEncryptionResponse\x12\x44\n\x10\x66ield_encryption\x18\x01 \x01(\x0b\x32\x19.admin.v1.FieldEncryptionR\x0f\x66ieldEncryption\"J\n%GetFieldEncryptionsByDatastoreRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\"p\n&GetFieldEncryptionsByDatastoreResponse\x12\x46\n\x11\x66ield_encryptions\x18\x01 \x03(\x0b\x32\x19.admin.v1.FieldEncryptionR\x10\x66ieldEncryptions\"q\n\x1c\x44\x65leteFieldEncryptionRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12.\n\x13\x66ield_encryption_id\x18\x02 \x01(\tR\x11\x66ieldEncryptionId\"B\n\x1d\x44\x65leteFieldEncryptionResponse\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\"\xc5\x01\n\x0f\x46ieldEncryption\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1f\n\x0bkey_storage\x18\x04 \x01(\tR\nkeyStorage\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12\x1d\n\nkey_region\x18\x06 \x01(\tR\tkeyRegion\x12\x10\n\x03\x61lg\x18\x07 \x01(\tR\x03\x61lg2\xd5\x02\n\x1c\x46ieldEncryptionPolicyService\x12\xa9\x01\n*CreateOrUpdateDefaultFieldEncryptionPolicy\x12;.admin.v1.CreateOrUpdateDefaultFieldEncryptionPolicyRequest\x1a<.admin.v1.CreateOrUpdateDefaultFieldEncryptionPolicyResponse\"\x00\x12\x88\x01\n\x1fGetDefaultFieldEncryptionPolicy\x12\x30.admin.v1.GetDefaultFieldEncryptionPolicyRequest\x1a\x31.admin.v1.GetDefaultFieldEncryptionPolicyResponse\"\x00\x32\xf8\x02\n\x16\x46ieldEncryptionService\x12j\n\x15\x43reateFieldEncryption\x12&.admin.v1.CreateFieldEncryptionRequest\x1a\'.admin.v1.CreateFieldEncryptionResponse\"\x00\x12\x85\x01\n\x1eGetFieldEncryptionsByDatastore\x12/.admin.v1.GetFieldEncryptionsByDatastoreRequest\x1a\x30.admin.v1.GetFieldEncryptionsByDatastoreResponse\"\x00\x12j\n\x15\x44\x65leteFieldEncryption\x12&.admin.v1.DeleteFieldEncryptionRequest\x1a\'.admin.v1.DeleteFieldEncryptionResponse\"\x00\x42\xaa\x01\n\x0c\x63om.admin.v1B\x0f\x45ncryptionProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.encryption_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017EncryptionProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_start=40
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_end=202
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_start=205
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_end=368
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_start=370
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_end=410
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_start=413
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_end=565
  _globals['_DEFAULTFIELDENCRYPTIONPOLICY']._serialized_start=568
  _globals['_DEFAULTFIELDENCRYPTIONPOLICY']._serialized_end=740
  _globals['_CREATEFIELDENCRYPTIONREQUEST']._serialized_start=743
  _globals['_CREATEFIELDENCRYPTIONREQUEST']._serialized_end=902
  _globals['_CREATEFIELDENCRYPTIONRESPONSE']._serialized_start=904
  _globals['_CREATEFIELDENCRYPTIONRESPONSE']._serialized_end=1005
  _globals['_GETFIELDENCRYPTIONSBYDATASTOREREQUEST']._serialized_start=1007
  _globals['_GETFIELDENCRYPTIONSBYDATASTOREREQUEST']._serialized_end=1081
  _globals['_GETFIELDENCRYPTIONSBYDATASTORERESPONSE']._serialized_start=1083
  _globals['_GETFIELDENCRYPTIONSBYDATASTORERESPONSE']._serialized_end=1195
  _globals['_DELETEFIELDENCRYPTIONREQUEST']._serialized_start=1197
  _globals['_DELETEFIELDENCRYPTIONREQUEST']._serialized_end=1310
  _globals['_DELETEFIELDENCRYPTIONRESPONSE']._serialized_start=1312
  _globals['_DELETEFIELDENCRYPTIONRESPONSE']._serialized_end=1378
  _globals['_FIELDENCRYPTION']._serialized_start=1381
  _globals['_FIELDENCRYPTION']._serialized_end=1578
  _globals['_FIELDENCRYPTIONPOLICYSERVICE']._serialized_start=1581
  _globals['_FIELDENCRYPTIONPOLICYSERVICE']._serialized_end=1922
  _globals['_FIELDENCRYPTIONSERVICE']._serialized_start=1925
  _globals['_FIELDENCRYPTIONSERVICE']._serialized_end=2301
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ETLGroup(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class ETLConnector(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "destination_id", "group_id", "connector_type", "service_name", "host_name", "database_name", "last_synced"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    HOST_NAME_FIELD_NUMBER: _ClassVar[int]
    DATABASE_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_SYNCED_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    destination_id: str
    group_id: str
    connector_type: str
    service_name: str
    host_name: str
    database_name: str
    last_synced: int
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., destination_id: _Optional[str] = ..., group_id: _Optional[str] = ..., connector_type: _Optional[str] = ..., service_name: _Optional[str] = ..., host_name: _Optional[str] = ..., database_name: _Optional[str] = ..., last_synced: _Optional[int] = ...) -> None: ...

class ETLDestination(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "group_id", "destination_type", "service_name", "host_name", "database_name", "last_synced"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    HOST_NAME_FIELD_NUMBER: _ClassVar[int]
    DATABASE_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_SYNCED_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    group_id: str
    destination_type: str
    service_name: str
    host_name: str
    database_name: str
    last_synced: int
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., group_id: _Optional[str] = ..., destination_type: _Optional[str] = ..., service_name: _Optional[str] = ..., host_name: _Optional[str] = ..., database_name: _Optional[str] = ..., last_synced: _Optional[int] = ...) -> None: ...

class ETLSchemaLineage(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "connector_id", "destination_id", "source_schema", "destination_schema", "last_updated"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    connector_id: str
    destination_id: str
    source_schema: str
    destination_schema: str
    last_updated: int
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., connector_id: _Optional[str] = ..., destination_id: _Optional[str] = ..., source_schema: _Optional[str] = ..., destination_schema: _Optional[str] = ..., last_updated: _Optional[int] = ...) -> None: ...

class ETLTableLineage(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "connector_id", "destination_id", "schema_id", "source_table", "destination_table", "last_updated"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TABLE_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_TABLE_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    connector_id: str
    destination_id: str
    schema_id: str
    source_table: str
    destination_table: str
    last_updated: int
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., connector_id: _Optional[str] = ..., destination_id: _Optional[str] = ..., schema_id: _Optional[str] = ..., source_table: _Optional[str] = ..., destination_table: _Optional[str] = ..., last_updated: _Optional[int] = ...) -> None: ...

class ETLColumnLineage(_message.Message):
    __slots__ = ["id", "org_id", "platform_id", "connector_id", "destination_id", "schema_id", "table_id", "source_column", "destination_column", "source_data_type", "destination_data_type", "is_primary_key", "is_foreign_key"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_COLUMN_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_COLUMN_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_PRIMARY_KEY_FIELD_NUMBER: _ClassVar[int]
    IS_FOREIGN_KEY_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    platform_id: str
    connector_id: str
    destination_id: str
    schema_id: str
    table_id: str
    source_column: str
    destination_column: str
    source_data_type: str
    destination_data_type: str
    is_primary_key: bool
    is_foreign_key: bool
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., platform_id: _Optional[str] = ..., connector_id: _Optional[str] = ..., destination_id: _Optional[str] = ..., schema_id: _Optional[str] = ..., table_id: _Optional[str] = ..., source_column: _Optional[str] = ..., destination_column: _Optional[str] = ..., source_data_type: _Optional[str] = ..., destination_data_type: _Optional[str] = ..., is_primary_key: bool = ..., is_foreign_key: bool = ...) -> None: ...

class ETLMapping(_message.Message):
    __slots__ = ["id", "org_id", "connector_id", "platform_connector_id", "platform_type", "last_synced"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ORG_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_TYPE_FIELD_NUMBER: _ClassVar[int]
    LAST_SYNCED_FIELD_NUMBER: _ClassVar[int]
    id: str
    org_id: str
    connector_id: str
    platform_connector_id: str
    platform_type: str
    last_synced: int
    def __init__(self, id: _Optional[str] = ..., org_id: _Optional[str] = ..., connector_id: _Optional[str] = ..., platform_connector_id: _Optional[str] = ..., platform_type: _Optional[str] = ..., last_synced: _Optional[int] = ...) -> None: ...



from .types.v1 import coderepo_pb2 as _coderepo_pb2
from .types.v1 import github_repository_pb2 as _github_repository_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteCodeRepoByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteCodeRepoByIdResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CancelDeleteCodeRepoByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class CancelDeleteCodeRepoByIdResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ConnectCodeRepositoryRequest(_message.Message):
    __slots__ = ["user_id", "type", "code"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    type: str
    code: str
    def __init__(self, user_id: _Optional[str] = ..., type: _Optional[str] = ..., code: _Optional[str] = ...) -> None: ...

class ConnectCodeRepositoryResponse(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class GetAccessTokenRequest(_message.Message):
    __slots__ = ["user_id", "type"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    type: str
    def __init__(self, user_id: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class GetAccessTokenResponse(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class GetGithubRepositoriesFromAuthUserRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class GetGithubRepositoriesFromAuthUserResponse(_message.Message):
    __slots__ = ["repositories"]
    REPOSITORIES_FIELD_NUMBER: _ClassVar[int]
    repositories: _containers.RepeatedCompositeFieldContainer[_github_repository_pb2.GithubRepository]
    def __init__(self, repositories: _Optional[_Iterable[_Union[_github_repository_pb2.GithubRepository, _Mapping]]] = ...) -> None: ...

class GetUserAccessTokenRequest(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class GetUserAccessTokenResponse(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class GetCodeReposRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetCodeReposResponse(_message.Message):
    __slots__ = ["repositories"]
    REPOSITORIES_FIELD_NUMBER: _ClassVar[int]
    repositories: _containers.RepeatedCompositeFieldContainer[_coderepo_pb2.CodeRepo]
    def __init__(self, repositories: _Optional[_Iterable[_Union[_coderepo_pb2.CodeRepo, _Mapping]]] = ...) -> None: ...

class CreateCodeRepoRequest(_message.Message):
    __slots__ = ["repository"]
    REPOSITORY_FIELD_NUMBER: _ClassVar[int]
    repository: _coderepo_pb2.CodeRepo
    def __init__(self, repository: _Optional[_Union[_coderepo_pb2.CodeRepo, _Mapping]] = ...) -> None: ...

class CreateCodeRepoResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Group(_message.Message):
    __slots__ = ["id", "name", "description", "active", "status", "roles", "created_at", "user_ids", "dsync_group_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    DSYNC_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    active: bool
    status: str
    roles: _containers.RepeatedCompositeFieldContainer[DbUser]
    created_at: _timestamp_pb2.Timestamp
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    dsync_group_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., active: bool = ..., status: _Optional[str] = ..., roles: _Optional[_Iterable[_Union[DbUser, _Mapping]]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user_ids: _Optional[_Iterable[str]] = ..., dsync_group_id: _Optional[str] = ...) -> None: ...

class DbUser(_message.Message):
    __slots__ = ["id", "db_username", "active", "status", "type", "expire_at", "created_at", "updated_at", "dsync_user_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DSYNC_USER_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    db_username: str
    active: bool
    status: str
    type: str
    expire_at: int
    created_at: int
    updated_at: int
    dsync_user_id: str
    def __init__(self, id: _Optional[str] = ..., db_username: _Optional[str] = ..., active: bool = ..., status: _Optional[str] = ..., type: _Optional[str] = ..., expire_at: _Optional[int] = ..., created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., dsync_user_id: _Optional[str] = ...) -> None: ...



from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Auth(_message.Message):
    __slots__ = ["type", "basic"]
    class Basic(_message.Message):
        __slots__ = ["username", "password"]
        USERNAME_FIELD_NUMBER: _ClassVar[int]
        PASSWORD_FIELD_NUMBER: _ClassVar[int]
        username: str
        password: str
        def __init__(self, username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    BASIC_FIELD_NUMBER: _ClassVar[int]
    type: str
    basic: Auth.Basic
    def __init__(self, type: _Optional[str] = ..., basic: _Optional[_Union[Auth.Basic, _Mapping]] = ...) -> None: ...

class CreateExternalApiIntegrationRequest(_message.Message):
    __slots__ = ["type", "name", "url", "auth"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    type: str
    name: str
    url: str
    auth: Auth
    def __init__(self, type: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ..., auth: _Optional[_Union[Auth, _Mapping]] = ...) -> None: ...

class CreateExternalApiIntegrationResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ApiIntegration(_message.Message):
    __slots__ = ["id", "type", "name", "url", "auth_type", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    name: str
    url: str
    auth_type: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ..., auth_type: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetExternalApiIntegrationRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetExternalApiIntegrationResponse(_message.Message):
    __slots__ = ["integration"]
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: ApiIntegration
    def __init__(self, integration: _Optional[_Union[ApiIntegration, _Mapping]] = ...) -> None: ...

class DeleteExternalApiIntegrationRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteExternalApiIntegrationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetExternalApiIntegrationsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetExternalApiIntegrationsResponse(_message.Message):
    __slots__ = ["integrations"]
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[ApiIntegration]
    def __init__(self, integrations: _Optional[_Iterable[_Union[ApiIntegration, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetClientAuthTokenRequest(_message.Message):
    __slots__ = ["user_id", "user_name", "user_email"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    USER_NAME_FIELD_NUMBER: _ClassVar[int]
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    user_name: str
    user_email: str
    def __init__(self, user_id: _Optional[str] = ..., user_name: _Optional[str] = ..., user_email: _Optional[str] = ...) -> None: ...

class GetClientAuthTokenResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...



import grpc


from .gen.admin.v1.search_pb2 import (
	SearchRequest,
	SearchResponse,
	WrappedSearchUser,
	WrappedSearchGroup,
	WrappedSearchPolicy,
	WrappedSearchDatastore,
	WrappedSearchSidecar,
	WrappedSearchInventory,
)

from .gen.admin.v1.search_pb2_grpc import SearchServiceStub
class SearchService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = SearchServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def Search(self, request: SearchRequest) -> SearchResponse:
		return self.stub.Search(request, metadata=self.headers)




# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import audit_pb2 as admin_dot_v1_dot_audit__pb2


class AuditLogsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetLogs = channel.unary_unary(
                '/admin.v1.AuditLogsService/GetLogs',
                request_serializer=admin_dot_v1_dot_audit__pb2.GetLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_audit__pb2.GetLogsResponse.FromString,
                )
        self.GetLogByID = channel.unary_unary(
                '/admin.v1.AuditLogsService/GetLogByID',
                request_serializer=admin_dot_v1_dot_audit__pb2.GetLogByIDRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_audit__pb2.GetLogByIDResponse.FromString,
                )
        self.GetEventBySession = channel.unary_unary(
                '/admin.v1.AuditLogsService/GetEventBySession',
                request_serializer=admin_dot_v1_dot_audit__pb2.GetEventBySessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_audit__pb2.GetEventBySessionResponse.FromString,
                )
        self.GetDataBySession = channel.unary_unary(
                '/admin.v1.AuditLogsService/GetDataBySession',
                request_serializer=admin_dot_v1_dot_audit__pb2.GetDataBySessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_audit__pb2.GetDataBySessionResponse.FromString,
                )


class AuditLogsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogByID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventBySession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataBySession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuditLogsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogs,
                    request_deserializer=admin_dot_v1_dot_audit__pb2.GetLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_audit__pb2.GetLogsResponse.SerializeToString,
            ),
            'GetLogByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogByID,
                    request_deserializer=admin_dot_v1_dot_audit__pb2.GetLogByIDRequest.FromString,
                    response_serializer=admin_dot_v1_dot_audit__pb2.GetLogByIDResponse.SerializeToString,
            ),
            'GetEventBySession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventBySession,
                    request_deserializer=admin_dot_v1_dot_audit__pb2.GetEventBySessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_audit__pb2.GetEventBySessionResponse.SerializeToString,
            ),
            'GetDataBySession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataBySession,
                    request_deserializer=admin_dot_v1_dot_audit__pb2.GetDataBySessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_audit__pb2.GetDataBySessionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.AuditLogsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuditLogsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AuditLogsService/GetLogs',
            admin_dot_v1_dot_audit__pb2.GetLogsRequest.SerializeToString,
            admin_dot_v1_dot_audit__pb2.GetLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AuditLogsService/GetLogByID',
            admin_dot_v1_dot_audit__pb2.GetLogByIDRequest.SerializeToString,
            admin_dot_v1_dot_audit__pb2.GetLogByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventBySession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AuditLogsService/GetEventBySession',
            admin_dot_v1_dot_audit__pb2.GetEventBySessionRequest.SerializeToString,
            admin_dot_v1_dot_audit__pb2.GetEventBySessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataBySession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AuditLogsService/GetDataBySession',
            admin_dot_v1_dot_audit__pb2.GetDataBySessionRequest.SerializeToString,
            admin_dot_v1_dot_audit__pb2.GetDataBySessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from .types.v1 import satellite_pb2 as _satellite_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSatelliteRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateSatelliteResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteByIdResponse(_message.Message):
    __slots__ = ["satellite"]
    SATELLITE_FIELD_NUMBER: _ClassVar[int]
    satellite: _satellite_pb2.Satellite
    def __init__(self, satellite: _Optional[_Union[_satellite_pb2.Satellite, _Mapping]] = ...) -> None: ...

class GetSatellitesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetSatellitesResponse(_message.Message):
    __slots__ = ["satellites"]
    SATELLITES_FIELD_NUMBER: _ClassVar[int]
    satellites: _containers.RepeatedCompositeFieldContainer[_satellite_pb2.Satellite]
    def __init__(self, satellites: _Optional[_Iterable[_Union[_satellite_pb2.Satellite, _Mapping]]] = ...) -> None: ...

class GetSatelliteApiKeyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteApiKeyResponse(_message.Message):
    __slots__ = ["api_key"]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    def __init__(self, api_key: _Optional[str] = ...) -> None: ...

class DeleteSatelliteRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteSatelliteResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...
